@@ -1,6 +1,6 @@
 # Verilog::Pli - Verilog PLI
-# $Id: Pli.pm,v 1.9 2000/01/21 15:15:40 wsnyder Exp $
-# Author: Wilson Snyder <wsnyder@world.std.com>
+# $Id: Pli.pm,v 1.11 2001/02/13 17:44:40 wsnyder Exp $
+# Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
 # This program is Copyright 2000 by Wilson Snyder.
@@ -76,7 +76,7 @@ C<http://www.ultranet.com/~wsnyder/verilog-perl>.
 
 =head1 AUTHORS
 
-Wilson Snyder <wsnyder@world.std.com>
+Wilson Snyder <wsnyder@wsnyder.org>
 
 =cut
 
@@ -94,7 +94,7 @@ use vars qw($VERSION);
 ######################################################################
 #### Configuration Section
 
-$VERSION = '1.3';
+$VERSION = '1.4';
 
 bootstrap Verilog::Pli;
 
