@@ -1,6 +1,6 @@
 # Verilog::Pli::IO - Verilog PLI - I/O rerouting
-# $Id: IO.pm,v 1.5 2000/01/21 15:15:44 wsnyder Exp $
-# Author: Wilson Snyder <wsnyder@world.std.com>
+# $Id: IO.pm,v 1.7 2001/02/13 17:44:44 wsnyder Exp $
+# Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
 # This program is Copyright 2000 by Wilson Snyder.
@@ -65,7 +65,7 @@ C<http://www.ultranet.com/~wsnyder/verilog-perl>.
 
 =head1 AUTHORS
 
-Wilson Snyder <wsnyder@world.std.com>
+Wilson Snyder <wsnyder@wsnyder.org>
 
 =cut
 ######################################################################
@@ -83,7 +83,7 @@ use Verilog::Pli;
 ######################################################################
 #### Configuration Section
 
-$VERSION = '1.3';
+$VERSION = '1.4';
 
 ######################################################################
 #### Package
